class Admin::ActivitiesController < OrbitMemberController
  layout "member_plugin"
  include Admin::PersonalActivitiesHelper

  before_action :set_activity, only: [:edit, :update, :destroy]
  #before_action :set_plugin

  #before_action :need_access_right
  #before_action :allow_admin_only, :only => [:index, :setting]

  def index
    @activities = Activity.order_by(:year => 'desc').page(params[:page]).per(10)
    #respond_to do |format|
      #format.html
      #format.xml  { render :xml => @activities }
    #end
  end

  def new
    @member = MemberProfile.find_by(:uid=>params['uid']) rescue nil
    @activity = Activity.new
    if params[:desktop]
      render :layout => false
    end
  end

  def create
    if !activity_params['member_profile_id'].blank?
      @member = MemberProfile.find(activity_params['member_profile_id']) rescue nil
    elsif !params[:author_members].blank?
      activity_params['member_profile_id'] = params[:author_members]
    else
      activity_params['member_profile_id'] = current_user.member_profile_id
    end
    @activity = Activity.new(activity_params)
    @activity.save
    redirect_to params['referer_url']
  end

  def edit
  end

  def update
    @activity.update_attributes(activity_params)
    redirect_to params['referer_url']
  end

  def destroy
    @activity.destroy
    respond_to do |format|
      format.html { redirect_to(admin_activities_url) }
      format.js
      format.json { render json: { "success" => true } }
    end
  end

  def analysis
  end

  def analysis_report
    role = params[:role_id]
    year_start = params[:year_start].to_i
    year_end = params[:year_end].to_i
    graph_by = params[:graph_by]

    @data = get_chart_data(year_start,year_end,role,params[:graph_by])

    render :layout => false
  end

  def download_excel_format
    respond_to do |format|
      format.xlsx {
        response.headers['Content-Disposition'] = 'attachment; filename="activities_format.xlsx"'
      }
    end
  end

  def download_excel
    year_start = params[:year_start].to_i
    year_end = params[:year_end].to_i
    @data = get_data_for_excel(year_start,year_end)
    respond_to do |format|
      format.xlsx {
        response.headers['Content-Disposition'] = 'attachment; filename="activities.xlsx"'
      }
    end
  end

  def import_from_excel
    workbook = RubyXL::Parser.parse(params["import_file"].tempfile)
    sheet = workbook[0]
    if sheet.count <= 503
      sheet.each_with_index do |row, i|
        next if i < 3
        user = User.where(:user_name => row.cells[0].value).first rescue nil
        if !user.nil?
          mp = user.member_profile
          import_this_activity(row,mp)
        end
      end
      redirect_to admin_activities_url
    else
      redirect_to admin_activities_url(:error => "1")
    end
  end

  private

  def set_activity
    path = request.path.split('/')
    if path.last.include? '-'
      uid = path[-1].split("-").last
      uid = uid.split("?").first
    else
      uid = path[-2].split("-").last
      uid = uid.split("?").first
    end
    @activity = Activity.find_by(:uid => uid) rescue Activity.find(params[:id])
  end

  def activity_params
    params.require(:activity).permit! rescue nil
  end
end
