class Activity
  include Mongoid::Document
  include Mongoid::Timestamps
  #include Mongoid::Attributes::Dynamic
  #include Admin::PersonalActivitiesHelper
  include OrbitModel::Status
  include MemberHelper
  include Slug
  belongs_to :member_profile

  # Language
  field :activity_name, as: :slug_title, type: String, localize: true
  field :activity_organizer, type: String, localize: true
  field :activity_area, type: String, localize: true

  # Basic
  field :year, type: String
  field :activity_start_date, type: DateTime
  field :activity_end_date, type: DateTime
  field :note, type: String

  # paginates_per 10
  
  has_many :activity_files, :autosave => true, :dependent => :destroy
  belongs_to :activity_category
  
  accepts_nested_attributes_for :activity_files, :allow_destroy => true
  before_validation :add_http
  scope :sort_for_frontend, ->{ where(:is_hidden=>false).order_by(:year => "desc", :publish_date => "desc") }

  def get_plugin_data(fields_to_show)
    plugin_datas = []
    fields_to_show.each do |field|
      plugin_data = self.get_plugin_field_data(field) rescue nil
      next if plugin_data.blank? or plugin_data['value'].blank?
      plugin_datas << plugin_data
    end
    plugin_datas
  end

  def self.get_plugin_datas_to_member(datas)
    fields_to_show = [
      "attendee",
      "activity_name",
      "activity_organizer",
      "activity_area",
      "activity_start_date",
      "activity_end_date"
    ]
    fields_to_remove = []

    pd_title = []
    
    fields_to_show.each do |t|
      if (self.fields[t].type.to_s == "String" || self.fields[t].type.to_s == "Object" rescue false)
        fields_to_remove << t if (datas.where(t.to_sym.ne => nil, t.to_sym.ne => "").count == 0 rescue false)
      else
        fields_to_remove << t if (datas.where(t.to_sym.ne => nil).count == 0 rescue false)
      end
      pd_title <<  {
          "plugin_data_title" => I18n.t("personal_activity.#{t}")
        } if !fields_to_remove.include?(t)
    end

    fields_to_show = fields_to_show - fields_to_remove

    plugin_datas = datas.sort_for_frontend.collect.with_index do |p, index|

      pd_data = []
      fields_to_show.collect do |t|
        if t == "activity_title"
          pd_data << { "data_title" => "<a href='#{OrbitHelper.url_to_plugin_show(p.to_param,'personal_activity')}' title='#{p.send(t)}'>#{p.send(t)}" }
        elsif t == "activity_category"
          pd_data << {"data_title" => (p.activity_category.title rescue "")}
        else
          pd_data << { "data_title" => p.send(t) }
        end
      end
      {
        "pd_datas" => pd_data,
        "type-sort" => (p.activity_category.sort_position.to_i rescue -1),
        "sort-index" => index
      }
    end
    plugin_datas = plugin_datas.sort_by{|pd| [pd["type-sort"], pd["sort-index"]]}
    return [pd_title,plugin_datas]
  end

  def get_plugin_field_data(field)
    case field
    when "language"
      value =  self.language.nil? ? "" : I18n.t(self.language) rescue ""
    when 'attendee'
      path = OrbitHelper.url_to_plugin_show(self.member_profile.to_param, 'member') rescue '#'
      value = "<a href='#{path}'>#{self.member_profile.name}</a>"
    when 'activity_name'
      value = self.activity_name rescue ''
    when 'activity_organizer'
      value = self.activity_organizer rescue ''
    when 'activity_area'
      value = self.activity_area rescue ''
    when 'activity_start_date'
      value = self.activity_start_date rescue ''
    when 'activity_end_date'
      value = self.activity_end_date rescue ''
    when 'year'
      value = self.year rescue ''
    when 'note'
      value = self.note rescue ''
    when "file"
      files = []
      self.research_files.each do |research_file|  
        url = research_file.file.url
        title = (research_file.title.blank? ? File.basename(research_file.file.path) : research_file.title)
        files << "<li><a href='#{url}' target='_blank'>#{title}</li>"
      end
      value = files.join("")
    else
      value = self.send(field) rescue ''
    end

    value = (value =~ /\A#{URI::regexp(['http', 'https'])}\z/) ? "<a href='#{value}' target='blank'>#{value}</a>" : value

    {
      'key' => field,
      'title_class' => "activity-#{field.gsub('_','-')}-field",
      'value_class' => "activity-#{field.gsub('_','-')}-value",
      'title' => I18n.t('personal_activity.'+ field),
      'value' => value
    }
  end

  protected
  def add_http
    unless self.url.blank? || self.url[/^http:\/\//] || self.url[/^https:\/\//]
      self.url = 'http://' + self.url
    end
  end

end
